import { createContext, useEffect, useRef, useState } from "react";
import type { Account } from "../types";
import { listen, type UnlistenFn } from "@tauri-apps/api/event";

interface AccountContextProps {
	children: JSX.Element | JSX.Element[];
}

interface AccountContextData {
	account: Account | null;
	setAccount: (account: Account | null) => void;
}

export const AccountContext = createContext<AccountContextData>({
	account: null,
	setAccount: () => {},
});

export default function AccountContextProvider(props: AccountContextProps) {
	const [account, setAccount] = useState<Account | null>(null);

	const unlistenRef = useRef<UnlistenFn | null>(null);

	useEffect(() => {
		listenLoginEvent();

		return () => {
			unlistenLoginEvent();
		};
	}, []);

	function listenLoginEvent() {
		listen<Account>("on-login", (event) => {
			setAccount(event.payload);
			// biome-ignore lint/suspicious/noAssignInExpressions: <explanation>
		}).then((unlistenFn) => (unlistenRef.current = unlistenFn));
	}

	function unlistenLoginEvent() {
		if (unlistenRef.current) {
			unlistenRef.current();
		}
	}

	return (
		<AccountContext.Provider value={{ account: account, setAccount }}>
			{props.children}
		</AccountContext.Provider>
	);
}
