import { invoke } from "@tauri-apps/api/core";
import { useState } from "react";
import { Button, Form, FormGroup, Input } from "reactstrap";

export default function LoginForm() {
	const [formData, setFormData] = useState<Record<string, string>>({});

	function handleOnInputChange(event: React.ChangeEvent<HTMLInputElement>) {
		const name = event.target.name;
		const value = event.target.value;

		setFormData({
			...formData,
			[name]: value,
		});
	}

	function handleOnLoginBtnClick(event: React.MouseEvent<HTMLButtonElement>) {
		event.preventDefault();

		invoke("login", { ...formData });
	}

	return (
		<Form>
			<FormGroup>
				<Input
					placeholder="URL vers le l'API du projet"
					name="url"
					onChange={handleOnInputChange}
					value={formData.url || ""}
				/>
			</FormGroup>

			<FormGroup>
				<Input
					placeholder="Nom d'utilisateur"
					name="username"
					onChange={handleOnInputChange}
					value={formData.username || ""}
				/>
			</FormGroup>

			<FormGroup>
				<Input
					type="password"
					placeholder="Mot de passe"
					name="password"
					onChange={handleOnInputChange}
					value={formData.password || ""}
				/>
			</FormGroup>

			<FormGroup>
				<Button onClick={handleOnLoginBtnClick}>Connexion</Button>
			</FormGroup>
		</Form>
	);
}
